@@ -1,4 +1,4 @@
-# version 1.1.0 September 25, 2015 by alexis.dinno@pdx.edu
+# version 1.1.1 January 6, 2016 by alexis.dinno@pdx.edu
 # perform Conover-Iman test of multiple comparisons using rank sums
 
 p.adjustment.methods <- c("none","bonferroni","sidak","holm","hs","hochberg","bh","by")
@@ -517,7 +517,7 @@ conover.test <- function(x=NA, g=NA, method=p.adjustment.methods, kw=TRUE, label
   if (table==TRUE) {
     # Need to determine how many tables (reps) to output
     reps      <- floor((k-1)/6)
-    laststart <- k - k%%6 + 1
+    laststart <- k - (reps*6) + 1
     kminusone <- k - 1
     if (label==FALSE) {
       g <- as.numeric(g)
